import React, { useState, useEffect } from 'react';

const UploadPage = ({ 
  photos, 
  setPhotos, 
  youTubeLink, 
  setYouTubeLink, 
  droneViewLink, 
  setDroneViewLink,
  mainFile,
  setMainFile // Add this prop to allow parent component to manage main file
}) => {
  const handlePhotoUpload = (e) => {
    const files = Array.from(e.target.files);
    // Use functional update to ensure correct state management
    setPhotos((prevPhotos) => [...prevPhotos, ...files]);
  };

  const removePhoto = (index) => {
    const newPhotos = photos.filter((_, i) => i !== index);
    setPhotos(newPhotos);
  };

  const handleMainFileUpload = (e) => {
    const file = e.target.files[0];
    setMainFile(file); // Use the prop method to update main file
  };

  return (
    <div className="w-full px-4 py-6 sm:px-6 lg:px-8">
      {/* Upload Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-4 text-gray-800">Upload Property Photos</h2>
        <div className="border-2 border-dashed border-purple-500 rounded-lg p-4 sm:p-6 flex flex-col items-center">
          <div className="flex flex-col items-center text-purple-500 mb-4">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="h-8 w-8 sm:h-12 sm:w-12 mb-2"
              viewBox="0 0 20 20"
              fill="currentColor"
            >
              <path d="M4 3a2 2 0 00-2 2v10a2 2 0 002 2h12a2 2 0 002-2V5a2 2 0 00-2-2H4zm7 5a1 1 0 00-2 0v3H7l3 3 3-3h-2V8z" />
            </svg>
            <p className="text-sm font-medium text-center">+ Add At Least 3 Photos</p>
          </div>
          <input 
            type="file" 
            multiple 
            accept="image/*" 
            onChange={handlePhotoUpload}
            className="hidden" 
            id="photo-upload"
          />
          <label 
            htmlFor="photo-upload" 
            className="mt-4 bg-purple-500 text-white py-2 px-4 rounded-lg hover:bg-purple-600 cursor-pointer text-sm sm:text-base"
          >
            Upload Photos
          </label>
        </div>
        
        {/* Uploaded Photos Preview */}
        {photos.length > 0 && (
          <>
            <div className="mt-4 grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-2">
              {photos.map((photo, index) => (
                <div key={index} className="relative">
                  <img 
                    src={URL.createObjectURL(photo)} 
                    alt={`Upload ${index + 1}`} 
                    className="w-full h-20 sm:h-24 object-cover rounded-lg"
                  />
                  <button 
                    onClick={() => removePhoto(index)}
                    className="absolute top-1 right-1 bg-red-500 text-white rounded-full p-1 text-xs"
                  >
                    X
                  </button>
                </div>
              ))}
            </div>
            
            {/* Uploaded Photo Names */}
            <div className="mt-4">
              <h3 className="font-semibold mb-2">Uploaded Photo Names:</h3>
              <ul className="list-disc pl-4">
                {photos.map((photo, index) => (
                  <li key={index} className="text-sm text-gray-700">{photo.name}</li>
                ))}
              </ul>
            </div>
          </>
        )}
      </div>

      {/* File Upload Section - Modified to Single Image */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">Upload Main File</h2>
        <input 
          type="file" 
          accept="image/*"
          onChange={handleMainFileUpload}
          className="w-full bg-purple-500 text-white py-2 px-4 rounded-lg hover:bg-purple-600 file:mr-4 file:rounded-lg file:border-0 file:bg-white file:px-4 file:py-2 file:text-purple-500 text-sm sm:text-base"
        />
        
        {/* Preview for Main Image */}
        {mainFile && (
          <div className="mt-4 relative">
            <img 
              src={URL.createObjectURL(mainFile)} 
              alt="Main Upload" 
              className="w-full h-48 object-cover rounded-lg"
            />
            <button 
              onClick={() => setMainFile(null)}
              className="absolute top-1 right-1 bg-red-500 text-white rounded-full p-1 text-xs"
            >
              X
            </button>
          </div>
        )}
      </div>

      {/* YouTube Link Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">YouTube Link</h2>
        <input
          type="text"
          placeholder="Enter YouTube link"
          value={youTubeLink}
          onChange={(e) => setYouTubeLink(e.target.value)}
          className="w-full border border-purple-500 rounded-lg py-2 px-4 focus:outline-none focus:ring-2 focus:ring-purple-600 text-sm sm:text-base"
        />
      </div>

      {/* Drone View Link Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">Drone View Link</h2>
        <input
          type="text"
          placeholder="Enter Drone View link"
          value={droneViewLink}
          onChange={(e) => setDroneViewLink(e.target.value)}
          className="w-full border border-purple-500 rounded-lg py-2 px-4 focus:outline-none focus:ring-2 focus:ring-purple-600 text-sm sm:text-base"
        />
      </div>
    </div>
  );
};

export default UploadPage;